@@ -909,7 +909,8 @@ BC_R(legend)(XLChartHandler const *handle,
 			   XL_pos);
 	case 3: pos = GOG_POSITION_E | GOG_POSITION_ALIGN_CENTER; break;
 	case 4: pos = GOG_POSITION_W | GOG_POSITION_ALIGN_CENTER; break;
-	case 7: break; /* treat floating legends as being on east */
+	case 7: /* treat floating legends as being on east */
+		pos = GOG_POSITION_E | GOG_POSITION_ALIGN_CENTER; break; 
 	};
 
 	legend = gog_object_add_by_name (GOG_OBJECT (s->chart), "Legend", NULL);
@@ -1270,36 +1271,33 @@ BC_R(scatter)(XLChartHandler const *handle,
 	      XLChartReadState *s, BiffQuery *q)
 {
 	g_return_val_if_fail (s->plot == NULL, TRUE);
-	s->plot = gog_plot_new_by_name ("GogXYPlot");
-	g_return_val_if_fail (s->plot != NULL, TRUE);
 
 	if (s->container.ver >= MS_BIFF_V8) {
 		guint16 const flags = GSF_LE_GET_GUINT16 (q->data+4);
 
 		/* Has bubbles */
 		if (flags & 0x01) {
-#if 0
 			guint16 const size_type = GSF_LE_GET_GUINT16 (q->data+2);
-			if (!(flags & 0x02))	/* hide negatives */
-			if (flags & 0x04)	/* in_3d */
-
-			/* huh ? */
-			xml_node_set_int (fmt, "percentage_largest_tochart",
-					  GSF_LE_GET_GUINT16 (q->data));
-			xmlNewChild (fmt, fmt->ns,
-				     (xmlChar *)((size_type == 2)
-					     ? "bubble_sized_as_width"
-					     : "bubble_sized_as_area"),
-				     NULL);
-	g_object_set (G_OBJECT (s->plot),
-		"type",			type,
-		/* "in_3d",		in_3d, */
-		NULL);
-
-#endif
+			gboolean in_3d = (flags & 0x04) != 0;
+			gboolean show_negatives = (flags & 0x02) != 0;
+			gboolean size_as_area = (size_type != 2);
+			float scale =  GSF_LE_GET_GUINT16 (q->data) / 100.;
+			s->plot = gog_plot_new_by_name ("GogBubblePlot");
+			g_return_val_if_fail (s->plot != NULL, TRUE);
+			g_object_set (G_OBJECT (s->plot),
+				"in_3d",		in_3d, 
+				"show_negatives",	show_negatives,
+				"size_as_area", 	size_as_area,
+				"bubble_scale",	scale,
+				NULL);
+			d(1, fprintf (stderr, "bubbles;"););
+			return FALSE;
 		}
 	}
 
+	s->plot = gog_plot_new_by_name ("GogXYPlot");
+	g_return_val_if_fail (s->plot != NULL, TRUE);
+
 	d(1, fprintf (stderr, "scatter;"););
 	return FALSE;
 }
@@ -1972,12 +1970,6 @@ chart_get_sheet (MSContainer const *container)
 	return ms_container_sheet (container->parent);
 }
 
-static GnmFormat *
-chart_get_fmt (MSContainer const *container, guint16 indx)
-{
-	return ms_container_get_fmt (container->parent, indx);
-}
-
 gboolean
 ms_excel_read_chart (BiffQuery *q, MSContainer *container, MsBiffVersion ver,
 		     SheetObject *sog)
@@ -1987,7 +1979,7 @@ ms_excel_read_chart (BiffQuery *q, MSContainer *container, MsBiffVersion ver,
 		chart_create_obj,
 		chart_parse_expr,
 		chart_get_sheet,
-		chart_get_fmt
+		NULL
 	};
 	int const num_handler = sizeof(chart_biff_handler) /
 		sizeof(XLChartHandler *);
