@@ -14,14 +14,14 @@
 
 GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 
-GtkType python_get_loader_type (ErrorInfo **ret_error);
+GType python_get_loader_type (ErrorInfo **ret_error);
 
 
 GType
 python_get_loader_type (ErrorInfo **ret_error)
 {
 	GNM_INIT_RET_ERROR_INFO (ret_error);
-	return TYPE_GNUMERIC_PLUGIN_LOADER_PYTHON;
+	return TYPE_GNM_PLUGIN_LOADER_PYTHON;
 }
 
 const ModulePluginUIVerbInfo console_ui_verbs[] = {
@@ -36,5 +36,5 @@ plugin_init (void)
 	   all dynamic types */
 	(void) gnm_py_interpreter_get_type ();
 	(void) gnm_python_get_type ();
-	(void) gnumeric_plugin_loader_python_get_type ();
+	(void) gnm_plugin_loader_python_get_type ();
 }
