@@ -9,7 +9,7 @@
 
 #define GNM_PY_INTERPRETER_SELECTOR_TYPE     (gnm_py_interpreter_selector_get_type ())
 #define GNM_PY_INTERPRETER_SELECTOR(o)       (G_TYPE_CHECK_INSTANCE_CAST ((o), GNM_PY_INTERPRETER_SELECTOR_TYPE, GnmPyInterpreterSelector))
-#define GNM_IS_PY_INTERPRETER_SELECTOR(o)    (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNM_PY_INTERPRETER_SELECTOR_TYPE))
+#define IS_GNM_PY_INTERPRETER_SELECTOR(o)    (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNM_PY_INTERPRETER_SELECTOR_TYPE))
 
 GType gnm_py_interpreter_selector_get_type (void);
 typedef struct _GnmPyInterpreterSelector GnmPyInterpreterSelector;
