@@ -75,7 +75,7 @@ struct _ItemGrid {
 		GdkGC      *bound;	/* the black line at the edge */
 	} gc;
 
-	Range bound;
+	GnmRange bound;
 
 	struct {
 		double x, y;
@@ -83,7 +83,7 @@ struct _ItemGrid {
 		FooCanvasItem *item;
 	} obj_create;
 
-	/* information for tha cursor motion handler */
+	/* information for the cursor motion handler */
 	guint cursor_timer;
 	double last_x, last_y;
 	GnmHLink *cur_link; /* do not derference, just a pointer */
@@ -195,17 +195,17 @@ item_grid_update (FooCanvasItem *item, double i2w_dx, double i2w_dy, int flags)
 static void
 item_grid_draw_merged_range (GdkDrawable *drawable, ItemGrid *ig,
 			     int start_x, int start_y,
-			     Range const *view, Range const *range,
+			     GnmRange const *view, GnmRange const *range,
 			     gboolean draw_selection)
 {
 	int l, r, t, b, last;
 	GdkGC *gc = ig->gc.empty;
 	SheetView const *sv = ((SheetControl *) ig->scg)->view;
 	Sheet const *sheet  = sv->sheet;
-	Cell  const *cell   = sheet_cell_get (sheet, range->start.col, range->start.row);
+	GnmCell  const *cell   = sheet_cell_get (sheet, range->start.col, range->start.row);
 
 	/* load style from corner which may not be visible */
-	MStyle const *style = sheet_style_get (sheet, range->start.col, range->start.row);
+	GnmStyle const *style = sheet_style_get (sheet, range->start.col, range->start.row);
 	gboolean const is_selected = draw_selection &&
 		(sv->edit_pos.col != range->start.col ||
 		 sv->edit_pos.row != range->start.row) &&
@@ -268,7 +268,7 @@ item_grid_draw_merged_range (GdkDrawable *drawable, ItemGrid *ig,
 
 static void
 item_grid_draw_background (GdkDrawable *drawable, ItemGrid *ig,
-			   MStyle const *style,
+			   GnmStyle const *style,
 			   int col, int row, int x, int y, int w, int h,
 			   gboolean draw_selection)
 {
@@ -290,7 +290,7 @@ item_grid_draw_background (GdkDrawable *drawable, ItemGrid *ig,
 }
 
 static gint
-merged_col_cmp (Range const *a, Range const *b)
+merged_col_cmp (GnmRange const *a, GnmRange const *b)
 {
 	return a->start.col - b->start.col;
 }
@@ -306,7 +306,7 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 	FooCanvas *canvas = item->canvas;
 	GnmCanvas *gcanvas = GNM_CANVAS (canvas);
 	Sheet const *sheet = ((SheetControl *) gcanvas->simple.scg)->sheet;
-	Cell const * const edit_cell = gcanvas->simple.scg->wbcg->wb_control.editing_cell;
+	GnmCell const * const edit_cell = gcanvas->simple.scg->wbcg->wb_control.editing_cell;
 	ItemGrid *ig = ITEM_GRID (item);
 	ColRowInfo const *ri = NULL, *next_ri = NULL;
 
@@ -325,13 +325,13 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 	int end_row = gnm_canvas_find_row (gcanvas, draw_y+height+2, NULL);
 	int const diff_y = y;
 
-	StyleRow sr, next_sr;
-	MStyle const **styles;
-	StyleBorder const **borders, **prev_vert;
-	StyleBorder const *none =
+	GnmRow sr, next_sr;
+	GnmStyle const **styles;
+	GnmBorder const **borders, **prev_vert;
+	GnmBorder const *none =
 		sheet->hide_grid ? NULL : style_border_none ();
 
-	Range     view;
+	GnmRange     view;
 	GSList	 *merged_active, *merged_active_seen,
 		 *merged_used, *merged_unused, *ptr, **lag;
 
@@ -382,8 +382,8 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 
 	/*
 	 * allocate a single blob of memory for all 8 arrays of pointers.
-	 *	- 6 arrays of n StyleBorder const *
-	 *	- 2 arrays of n MStyle const *
+	 *	- 6 arrays of n GnmBorder const *
+	 *	- 2 arrays of n GnmStyle const *
 	 */
 	n = end_col - start_col + 3; /* 1 before, 1 after, 1 fencepost */
 	style_row_init (&prev_vert, &sr, &next_sr, start_col, end_col,
@@ -442,7 +442,7 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 		view.start.row = row;
 		lag = &merged_unused;
 		for (ptr = merged_unused; ptr != NULL; ) {
-			Range * const r = ptr->data;
+			GnmRange * const r = ptr->data;
 
 			if (r->start.row <= row) {
 				GSList *tmp = ptr;
@@ -470,13 +470,13 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 		}
 
 		for (col = start_col, x = diff_x; col <= end_col ; col++) {
-			MStyle const *style;
+			GnmStyle const *style;
 			CellSpanInfo const *span;
 			ColRowInfo const *ci = sheet_col_get_info (sheet, col);
 
 			if (!ci->visible) {
 				if (merged_active != NULL) {
-					Range const *r = merged_active->data;
+					GnmRange const *r = merged_active->data;
 					if (r->end.col == col) {
 						ptr = merged_active;
 						merged_active = merged_active->next;
@@ -496,7 +496,7 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 
 			/* Skip any merged regions */
 			if (merged_active != NULL) {
-				Range const *r = merged_active->data;
+				GnmRange const *r = merged_active->data;
 				if (r->start.col <= col) {
 					gboolean clear_top, clear_bottom = FALSE;
 					int i, first = r->start.col;
@@ -566,8 +566,8 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 				 * contents extending past the edge of the edit
 				 * box.  Ignore blanks too.
 				 */
-				Cell const *cell = sheet_cell_get (sheet, col, row);
-				if (!cell_is_blank (cell) && cell != edit_cell)
+				GnmCell const *cell = sheet_cell_get (sheet, col, row);
+				if (!cell_is_empty (cell) && cell != edit_cell)
 					cell_draw (cell,
 						   ig->gc.cell, drawable,
 						   x, y, -1, -1, -1);
@@ -578,7 +578,7 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 			 */
 			} else if (edit_cell != span->cell &&
 				   (col == span->right || col == end_col)) {
-				Cell const *cell = span->cell;
+				GnmCell const *cell = span->cell;
 				int const start_span_col = span->left;
 				int const end_span_col = span->right;
 				int real_x = x;
@@ -628,7 +628,7 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 
 		/* In case there were hidden merges that trailed off the end */
 		while (merged_active != NULL) {
-			Range const *r = merged_active->data;
+			GnmRange const *r = merged_active->data;
 			ptr = merged_active;
 			merged_active = merged_active->next;
 			if (r->end.row <= row) {
@@ -656,12 +656,12 @@ item_grid_draw (FooCanvasItem *item, GdkDrawable *drawable,
 		style_borders_row_draw (prev_vert, &sr,
 					drawable, diff_x, y, y, colwidths, FALSE);
 		if (gcanvas->pane->index >= 2)
-			gdk_draw_line (drawable, ig->gc.bound, 0, y, x, y);
+			gdk_draw_line (drawable, ig->gc.bound, diff_x, y, x, y);
 	}
 	if (col >= ig->bound.end.col &&
 	    /* TODO : Add pane flags to avoid hard coding pane numbers */
 	    (gcanvas->pane->index == 1 || gcanvas->pane->index == 2))
-		gdk_draw_line (drawable, ig->gc.bound, x, 0, x, y);
+		gdk_draw_line (drawable, ig->gc.bound, x, diff_y, x, y);
 
 	g_slist_free (merged_used);	   /* merges with bottom in view */
 	g_slist_free (merged_active_seen); /* merges with bottom the view */
@@ -867,7 +867,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	SheetControlGUI *scg = ig->scg;
 	SheetControl *sc = (SheetControl *) scg;
 	Sheet *sheet = sc->sheet;
-	CellPos	pos;
+	GnmCellPos	pos;
 	int x, y;
 	gboolean edit_showed_dialog;
 	gboolean already_selected;
@@ -878,7 +878,7 @@ item_grid_button_press (ItemGrid *ig, GdkEventButton *event)
 	pos.col = gnm_canvas_find_col (gcanvas, x, NULL);
 	pos.row = gnm_canvas_find_row (gcanvas, y, NULL);
 
-	/* Range check first */
+	/* GnmRange check first */
 	if (pos.col >= SHEET_MAX_COLS)
 		return TRUE;
 	if (pos.row >= SHEET_MAX_ROWS)
@@ -1038,7 +1038,7 @@ cb_cursor_come_to_rest (ItemGrid *ig)
 	GnmCanvas *gcanvas = GNM_CANVAS (canvas);
 	GnmHLink *link;
 	int x, y;
-	CellPos pos;
+	GnmCellPos pos;
 	const char *tiptext;
 
 	/* Be anal and look it up in case something has destroyed the link
@@ -1069,9 +1069,10 @@ cb_cursor_motion (ItemGrid *ig)
 	FooCanvas *canvas = ig->canvas_item.canvas;
 	GnmCanvas *gcanvas = GNM_CANVAS (canvas);
 	int x, y;
-	GnmCursorType cursor;
-	CellPos pos;
+	GdkCursor *cursor;
+	GnmCellPos pos;
 	GnmHLink *old_link;
+	GdkDisplay *display;
 
 	foo_canvas_w2c (canvas, ig->last_x, ig->last_y, &x, &y);
 	pos.col = gnm_canvas_find_col (gcanvas, x, NULL);
@@ -1079,13 +1080,23 @@ cb_cursor_motion (ItemGrid *ig)
 
 	old_link = ig->cur_link;
 	ig->cur_link = sheet_hlink_find (sheet, &pos);
-	cursor = (NULL == ig->cur_link) ? GNM_CURSOR_FAT_CROSS : GNM_CURSOR_PRESS;
-
-	ig->cursor_timer = 0;
-	if (gcanvas->pane->cursor_type != cursor) {
-		gcanvas->pane->cursor_type = cursor;
+	display = gtk_widget_get_display (GTK_WIDGET (canvas));
+	if (ig->cur_link)
+		cursor = gdk_cursor_new_for_display (display, GDK_HAND2);
+	else
+		cursor = gnm_fat_cross_cursor (display);
+						     
+	if (gcanvas->pane->mouse_cursor != cursor) {
+		gnm_pane_mouse_cursor_set (gcanvas->pane, cursor);
 		scg_set_display_cursor (ig->scg);
 	}
+	gdk_cursor_unref (cursor);
+
+	if (ig->cursor_timer != 0) {
+		g_source_remove (ig->cursor_timer);
+		ig->cursor_timer = 0;
+	}
+
 	if (old_link != ig->cur_link && ig->tip != NULL) {
 		gtk_widget_destroy (gtk_widget_get_toplevel (ig->tip));
 		ig->tip = NULL;
@@ -1149,7 +1160,7 @@ item_grid_event (FooCanvasItem *item, GdkEvent *event)
 				wbcg_get_entry_logical (scg->wbcg), TRUE);
 
 		if (selecting == ITEM_GRID_SELECTING_CELL_RANGE) {
-			CellPos const *pos = sv_is_singleton_selected (sc_view (sc));
+			GnmCellPos const *pos = sv_is_singleton_selected (sc_view (sc));
 			if (pos != NULL) {
 				GnmHLink *link;
 				/* check for hyper links */
@@ -1244,7 +1255,7 @@ item_grid_set_property (GObject *obj, guint param_id,
 			GValue const *value, GParamSpec *pspec)
 {
 	ItemGrid *ig = ITEM_GRID (obj);
-	Range const *r;
+	GnmRange const *r;
 
 	switch (param_id) {
 	case ITEM_GRID_PROP_SHEET_CONTROL_GUI :
