@@ -154,7 +154,7 @@ load_hf (char const *type, char const *a, char const *b, char const *c)
 }
 
 static gboolean
-load_range (char const *name, Range *r)
+load_range (char const *name, GnmRange *r)
 {
 	gboolean success = FALSE;
 	char *str = gnome_config_get_string (name);
@@ -257,8 +257,6 @@ print_info_new (void)
 
 	gnome_config_push_prefix ("/Gnumeric/Print/");
 
-	pi->n_copies = gnome_config_get_int ("num_copies=1");
-
 	pi->orientation = gnome_config_get_bool ("vertical_print=false")
 		? PRINT_ORIENT_VERTICAL : PRINT_ORIENT_HORIZONTAL;
 
@@ -400,7 +398,6 @@ print_info_save (PrintInformation const *pi)
 
 	gnome_config_push_prefix ("/Gnumeric/Print/");
 
-	gnome_config_set_int ("num_copies", pi->n_copies);
 	gnome_config_set_bool ("vertical_print", pi->orientation == PRINT_ORIENT_VERTICAL);
 	gnome_config_set_bool ("do_scale_percent", pi->scaling.type == PERCENTAGE);
 	gnome_config_set_float ("scale_percent", pi->scaling.percentage.x);
@@ -492,7 +489,7 @@ render_pages (GString *target, HFRenderInfo *info, char const *args)
 static void
 render_value_with_format (GString *target, char const *number_format, HFRenderInfo *info)
 {
-	StyleFormat *format;
+	GnmFormat *format;
 
 	/* TODO : Check this assumption.  Is it a localized format ?? */
 	format = style_format_new_XL (number_format, FALSE);
@@ -557,12 +554,9 @@ render_path (GString *target, HFRenderInfo *info, char const *args)
 			g_free (current_dir);
 		}
 		dir = g_path_get_dirname (path_n_file);
-		path = g_build_path (G_DIR_SEPARATOR_S, dir, 
-				     G_DIR_SEPARATOR_S, NULL);
-		g_string_append (target, path);
-		g_free (path);
-		g_free (path_n_file);
+		g_string_append (target, dir);
 		g_free (dir);
+		g_free (path_n_file);
 	} else 
 		g_string_append (target, _("Path "));
 }
@@ -808,3 +802,13 @@ print_info_set_margins (PrintInformation *pi,
 	print_info_set_margin_left (pi, left);
 	print_info_set_margin_right (pi, right);
 }
+
+void        
+print_info_set_n_copies  (PrintInformation *pi, guint copies)
+{
+	g_return_if_fail (pi->print_config != NULL);
+
+	gnome_print_config_set_int (pi->print_config, 
+				    GNOME_PRINT_KEY_NUM_COPIES, 
+				    (gint)copies);
+}
