@@ -70,7 +70,7 @@ static GType filter_field_get_type (void);
 
 
 GnmFilterCondition *
-gnm_filter_condition_new_single (GnmFilterOp op, Value *v)
+gnm_filter_condition_new_single (GnmFilterOp op, GnmValue *v)
 {
 	GnmFilterCondition *res = g_new0 (GnmFilterCondition, 1);
 	res->op[0] = op;	res->op[1] = GNM_FILTER_UNUSED;
@@ -79,9 +79,9 @@ gnm_filter_condition_new_single (GnmFilterOp op, Value *v)
 }
 
 GnmFilterCondition *
-gnm_filter_condition_new_double (GnmFilterOp op0, Value *v0,
+gnm_filter_condition_new_double (GnmFilterOp op0, GnmValue *v0,
 				 gboolean join_with_and,
-				 GnmFilterOp op1, Value *v1)
+				 GnmFilterOp op1, GnmValue *v1)
 {
 	GnmFilterCondition *res = g_new0 (GnmFilterCondition, 1);
 	res->op[0] = op0;	res->op[1] = op1;
@@ -243,7 +243,7 @@ cb_filter_button_release (GtkWidget *popup, GdkEventButton *event,
 	    gtk_tree_selection_get_selected (gtk_tree_view_get_selection (list),
 					     NULL, &iter)) {
 		char	*label;
-		Value   *val;
+		GnmValue   *val;
 		int	 type;
 		gboolean set_condition = TRUE;
 
@@ -254,7 +254,7 @@ cb_filter_button_release (GtkWidget *popup, GdkEventButton *event,
 		field_num = filter_field_index (field);
 		switch (type) {
 		case  0 : cond = gnm_filter_condition_new_single (
-				  GNM_FILTER_OP_EQUAL, value_duplicate (val));
+				  GNM_FILTER_OP_EQUAL, value_dup (val));
 			break;
 		case  1 : cond = NULL;	break; /* unfilter */
 		case  2 : /* Custom */
@@ -312,8 +312,8 @@ typedef struct {
 	GHashTable *hash;
 } UniqueCollection;
 
-static Value *
-cb_collect_unique (Sheet *sheet, int col, int row, Cell *cell,
+static GnmValue *
+cb_collect_unique (Sheet *sheet, int col, int row, GnmCell *cell,
 		   UniqueCollection *uc)
 {
 	if (cell_is_blank (cell))
@@ -324,7 +324,7 @@ cb_collect_unique (Sheet *sheet, int col, int row, Cell *cell,
 	return NULL;
 }
 static void
-cb_copy_hash_to_array (Value *key, gpointer value, gpointer sorted)
+cb_copy_hash_to_array (GnmValue *key, gpointer value, gpointer sorted)
 {
 	g_ptr_array_add (sorted, key);
 }
@@ -339,9 +339,9 @@ collect_unique_elements (GnmFilterField *field,
 	GPtrArray    *sorted = g_ptr_array_new ();
 	unsigned i;
 	gboolean is_custom = FALSE;
-	Range	 r = field->filter->r;
-	Value const *check = NULL;
-	Value	    *check_num = NULL; /* XL stores numbers as string @$^!@$ */
+	GnmRange	 r = field->filter->r;
+	GnmValue const *check = NULL;
+	GnmValue	    *check_num = NULL; /* XL stores numbers as string @$^!@$ */
 
 	if (field->cond != NULL &&
 	    field->cond->op[0] == GNM_FILTER_OP_EQUAL &&
@@ -387,9 +387,9 @@ collect_unique_elements (GnmFilterField *field,
 	g_hash_table_foreach (uc.hash,
 		(GHFunc) cb_copy_hash_to_array, sorted);
 	qsort (&g_ptr_array_index (sorted, 0),
-	       sorted->len, sizeof (Value *), value_cmp);
+	       sorted->len, sizeof (GnmValue *), value_cmp);
 	for (i = 0; i < sorted->len ; i++) {
-		Value const *v = g_ptr_array_index (sorted, i);
+		GnmValue const *v = g_ptr_array_index (sorted, i);
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
 			0, value_peek_string (v),
@@ -594,8 +594,8 @@ filter_field_class_init (GObjectClass *object_class)
 	/* SheetObject class method overrides */
 	sheet_object_class->update_view_bounds = filter_field_update_bounds;
 	sheet_object_class->new_view	  = filter_field_new_view;
-	sheet_object_class->read_xml      = NULL;
-	sheet_object_class->write_xml     = NULL;
+	sheet_object_class->read_xml_dom  = NULL;
+	sheet_object_class->write_xml_dom = NULL;
 	sheet_object_class->print         = NULL;
 	sheet_object_class->clone         = NULL;
 }
@@ -608,7 +608,7 @@ GSF_CLASS (GnmFilterField, filter_field,
 
 typedef struct  {
 	GnmFilterCondition const *cond;
-	Value		 *val[2];
+	GnmValue		 *val[2];
 	gnumeric_regex_t  regexp[2];
 	GnmDateConventions const *date_conv;
 } FilterExpr;
@@ -618,7 +618,7 @@ filter_expr_init (FilterExpr *fexpr, unsigned i,
 		  GnmFilterCondition const *cond,
 		  GnmFilter const *filter)
 {
-	Value *tmp = cond->value[i];
+	GnmValue *tmp = cond->value[i];
 	fexpr->date_conv = workbook_date_conv (filter->sheet->workbook);
 
 	if (VALUE_IS_STRING (tmp)) {
@@ -631,7 +631,7 @@ filter_expr_init (FilterExpr *fexpr, unsigned i,
 		    gnumeric_regcomp_XL (fexpr->regexp + i,  str, REG_ICASE) == REG_OK)
 			return;
 	}
-	fexpr->val[i] = value_duplicate (tmp);
+	fexpr->val[i] = value_dup (tmp);
 }
 
 static void
@@ -644,10 +644,10 @@ filter_expr_release (FilterExpr *fexpr, unsigned i)
 }
 
 static gboolean
-filter_expr_eval (GnmFilterOp op, Value const *src, gnumeric_regex_t const *regexp,
-		  Value *target)
+filter_expr_eval (GnmFilterOp op, GnmValue const *src, gnumeric_regex_t const *regexp,
+		  GnmValue *target)
 {
-	ValueCompare cmp;
+	GnmValDiff cmp;
 
 	if (src == NULL) {
 		char const *str = value_peek_string (target);
@@ -677,8 +677,8 @@ filter_expr_eval (GnmFilterOp op, Value const *src, gnumeric_regex_t const *rege
 	};
 }
 
-static Value *
-cb_filter_expr (Sheet *sheet, int col, int row, Cell *cell,
+static GnmValue *
+cb_filter_expr (Sheet *sheet, int col, int row, GnmCell *cell,
 		FilterExpr const *fexpr)
 {
 	if (cell != NULL) {
@@ -703,16 +703,16 @@ cb_filter_expr (Sheet *sheet, int col, int row, Cell *cell,
 
 /*****************************************************************************/
 
-static Value *
-cb_filter_non_blanks (Sheet *sheet, int col, int row, Cell *cell, gpointer data)
+static GnmValue *
+cb_filter_non_blanks (Sheet *sheet, int col, int row, GnmCell *cell, gpointer data)
 {
 	if (cell_is_blank (cell))
 		colrow_set_visibility (sheet, FALSE, FALSE, row, row);
 	return NULL;
 }
 
-static Value *
-cb_filter_blanks (Sheet *sheet, int col, int row, Cell *cell, gpointer data)
+static GnmValue *
+cb_filter_blanks (Sheet *sheet, int col, int row, GnmCell *cell, gpointer data)
 {
 	if (!cell_is_blank (cell))
 		colrow_set_visibility (sheet, FALSE, FALSE, row, row);
@@ -725,17 +725,17 @@ typedef struct {
 	unsigned count;
 	unsigned elements;
 	gboolean find_max;
-	Value const **vals;
+	GnmValue const **vals;
 } FilterItems;
 
-static Value *
-cb_filter_find_items (Sheet *sheet, int col, int row, Cell *cell,
+static GnmValue *
+cb_filter_find_items (Sheet *sheet, int col, int row, GnmCell *cell,
 		      FilterItems *data)
 {
-	Value const *v = cell->value;
+	GnmValue const *v = cell->value;
 	if (data->elements >= data->count) {
 		unsigned j, i = data->elements;
-		ValueCompare const cond = data->find_max ? IS_GREATER : IS_LESS;
+		GnmValDiff const cond = data->find_max ? IS_GREATER : IS_LESS;
 		while (i-- > 0)
 			if (value_compare (v, data->vals[i], TRUE) == cond) {
 				for (j = 0; j < i ; j++)
@@ -747,20 +747,20 @@ cb_filter_find_items (Sheet *sheet, int col, int row, Cell *cell,
 		data->vals [data->elements++] = v;
 		if (data->elements == data->count) {
 			qsort (data->vals, data->elements,
-			       sizeof (Value *),
+			       sizeof (GnmValue *),
 			       data->find_max ? value_cmp : value_cmp_reverse);
 		}
 	}
 	return NULL;
 }
 
-static Value *
-cb_hide_unwanted_items (Sheet *sheet, int col, int row, Cell *cell,
+static GnmValue *
+cb_hide_unwanted_items (Sheet *sheet, int col, int row, GnmCell *cell,
 			FilterItems const *data)
 {
 	if (cell != NULL) {
 		int i = data->elements;
-		Value const *v = cell->value;
+		GnmValue const *v = cell->value;
 
 		while (i-- > 0)
 			if (data->vals[i] == v)
@@ -777,8 +777,8 @@ typedef struct {
 	gnm_float	low, high;
 } FilterPercentage;
 
-static Value *
-cb_filter_find_percentage (Sheet *sheet, int col, int row, Cell *cell,
+static GnmValue *
+cb_filter_find_percentage (Sheet *sheet, int col, int row, GnmCell *cell,
 			   FilterPercentage *data)
 {
 	if (VALUE_IS_NUMBER (cell->value)) {
@@ -797,8 +797,8 @@ cb_filter_find_percentage (Sheet *sheet, int col, int row, Cell *cell,
 	return NULL;
 }
 
-static Value *
-cb_hide_unwanted_percentage (Sheet *sheet, int col, int row, Cell *cell,
+static GnmValue *
+cb_hide_unwanted_percentage (Sheet *sheet, int col, int row, GnmCell *cell,
 			     FilterPercentage const *data)
 {
 	if (cell != NULL && VALUE_IS_NUMBER (cell->value)) {
@@ -878,7 +878,7 @@ filter_field_apply (GnmFilterField *field)
 			data.find_max = (field->cond->op[0] & 0x1) ? FALSE : TRUE;
 			data.elements    = 0;
 			data.count  = field->cond->count;
-			data.vals   = g_alloca (sizeof (Value *) * data.count);
+			data.vals   = g_alloca (sizeof (GnmValue *) * data.count);
 			sheet_foreach_cell_in_range (filter->sheet,
 				CELL_ITER_IGNORE_HIDDEN | CELL_ITER_IGNORE_BLANK,
 				col, start_row, col, end_row,
@@ -917,7 +917,7 @@ gnm_filter_add_field (GnmFilter *filter, int i)
 	};
 	static float const offsets [4] = { .0, .0, 0., 0. };
 	int n;
-	Range tmp;
+	GnmRange tmp;
 	SheetObjectAnchor anchor;
 	GnmFilterField *field = g_object_new (filter_field_get_type (), NULL);
 
@@ -945,7 +945,7 @@ gnm_filter_add_field (GnmFilter *filter, int i)
  * Init a filter
  **/
 GnmFilter *
-gnm_filter_new (Sheet *sheet, Range const *r)
+gnm_filter_new (Sheet *sheet, GnmRange const *r)
 {
 	GnmFilter	*filter;
 	int i;
@@ -1098,18 +1098,83 @@ gnm_filter_set_condition (GnmFilter *filter, unsigned i,
 /**
  * gnm_filter_overlaps_range :
  * @filter : #GnmFilter
- * @r : #Range
+ * @r : #GnmRange
  *
- * Does the range filter by @filter overlap with Range @r
+ * Does the range filter by @filter overlap with GnmRange @r
  **/
 gboolean
-gnm_filter_overlaps_range (GnmFilter const *filter, Range const *r)
+gnm_filter_overlaps_range (GnmFilter const *filter, GnmRange const *r)
 {
 	g_return_val_if_fail (filter != NULL, FALSE);
 
 	return range_overlap (&filter->r, r);
 }
 
+/*************************************************************************/
+
+static gboolean
+sheet_cell_or_one_below_is_not_empty (Sheet *sheet, int col, int row)
+{
+	return !sheet_is_cell_empty (sheet, col, row) ||
+		(row < (SHEET_MAX_ROWS - 1) &&
+		 !sheet_is_cell_empty (sheet, col, row+1));
+}
+
+/**
+ * sheet_filter_guess_region :
+ * @sheet : #Sheet
+ * @range : #GnmRange
+ *
+ **/
+void
+sheet_filter_guess_region (Sheet *sheet, GnmRange *region)
+{
+	int col;
+	int end_row;
+	int offset;
+	
+	/* check in case only one cell selected */
+	if (region->start.col == region->end.col) {
+		int start = region->start.col;
+		/* look for previous empty column */
+		for (col = start - 1; col > 0; col--)
+			if (!sheet_cell_or_one_below_is_not_empty (sheet, col, region->start.row)) 
+				break;
+		region->start.col = col - 1;
+
+		/* look for next empty column */
+		for (col = start + 1; col < SHEET_MAX_COLS; col++)
+			if (!sheet_cell_or_one_below_is_not_empty (sheet, col, region->start.row)) 
+				break;
+		region->end.col = col - 1;
+	}		
+	
+	/* find first and last non-empty cells in region */
+	for (col = region->start.col; col <= region->end.col; col++)
+		if (sheet_cell_or_one_below_is_not_empty (sheet, col, region->start.row))
+			break;
+
+	if (col > region->end.col)
+		return; /* all empty -- give up */
+	region->start.col = col;
+	
+	for (col = region->end.col; col >= region->start.col; col--)
+		if (sheet_cell_or_one_below_is_not_empty(sheet, col, region->start.row))
+			break;
+	region->end.col = col;
+	
+	/* now find length of longest column */
+	for (col = region->start.col; col <= region->end.col; col++) {
+		offset = 0;
+		if (sheet_is_cell_empty(sheet, col, region->start.row))
+			offset = 1;
+		end_row = sheet_find_boundary_vertical (sheet, col,
+			region->start.row + offset, col, 1, TRUE);
+		if (end_row > region->end.row) 
+			region->end.row = end_row;
+	}
+}
+
 /**
  * sheet_filter_insdel_colrow :
  * @sheet :
