@@ -49,7 +49,7 @@
  * @expr0 : absorb the reference to the expression.
  * @expr1 : absorb the reference to the expression.
  */
-Validation *
+GnmValidation *
 validation_new (ValidationStyle style,
 		ValidationType  type,
 		ValidationOp    op,
@@ -57,13 +57,13 @@ validation_new (ValidationStyle style,
 		GnmExpr const *expr0, GnmExpr const *expr1,
 		gboolean allow_blank, gboolean use_dropdown)
 {
-	Validation *v;
+	GnmValidation *v;
 
-	v = g_new0 (Validation, 1);
+	v = g_new0 (GnmValidation, 1);
 	v->ref_count = 1;
 
-	v->title = title ? string_get (title) : NULL;
-	v->msg   = msg ? string_get (msg) : NULL;
+	v->title = title ? gnm_string_get (title) : NULL;
+	v->msg   = msg ? gnm_string_get (msg) : NULL;
 	v->expr[0] = expr0;
 	v->expr[1] = expr1;
 	v->style   = style;
@@ -76,14 +76,14 @@ validation_new (ValidationStyle style,
 }
 
 void
-validation_ref (Validation *v)
+validation_ref (GnmValidation *v)
 {
 	g_return_if_fail (v != NULL);
 	v->ref_count++;
 }
 
 void
-validation_unref (Validation *v)
+validation_unref (GnmValidation *v)
 {
 	int i;
 
@@ -93,11 +93,11 @@ validation_unref (Validation *v)
 
 	if (v->ref_count < 1) {
 		if (v->title != NULL) {
-			string_unref (v->title);
+			gnm_string_unref (v->title);
 			v->title = NULL;
 		}
 		if (v->msg != NULL) {
-			string_unref (v->msg);
+			gnm_string_unref (v->msg);
 			v->msg = NULL;
 		}
 		for (i = 0 ; i < 2 ; i++)
@@ -114,14 +114,14 @@ validation_unref (Validation *v)
  *
  * Either pass @expr or @val.
  * The parameters will be validated against the
- * validation set in the MStyle if applicable.
+ * validation set in the GnmStyle if applicable.
  **/
 ValidationStatus
-validation_eval (WorkbookControl *wbc, MStyle const *mstyle,
-		 Sheet *sheet, CellPos const *pos, gboolean *showed_dialog)
+validation_eval (WorkbookControl *wbc, GnmStyle const *mstyle,
+		 Sheet *sheet, GnmCellPos const *pos, gboolean *showed_dialog)
 {
-	Validation *v;
-	Cell	   *cell;
+	GnmValidation *v;
+	GnmCell	   *cell;
 	char	   *msg = NULL;
 	gboolean    allocated_msg = FALSE;
 	ValidationStatus result;
@@ -144,7 +144,7 @@ validation_eval (WorkbookControl *wbc, MStyle const *mstyle,
 				       cell_name (cell));
 	} else {
 		GnmExpr const *val_expr = NULL, *expr = NULL;
-		Value *val = cell->value;
+		GnmValue *val = cell->value;
 
 		switch (v->type) {
 		case VALIDATION_TYPE_ANY :
@@ -154,7 +154,7 @@ validation_eval (WorkbookControl *wbc, MStyle const *mstyle,
 		case VALIDATION_TYPE_AS_NUMBER :
 		case VALIDATION_TYPE_AS_DATE :		/* What the hell does this do */
 		case VALIDATION_TYPE_AS_TIME : {	/* What the hell does this do */
-			Value *res = NULL;
+			GnmValue *res = NULL;
 			/* we know it is not empty */
 			if (val->type == VALUE_ERROR) {
 				msg = g_strdup_printf (_("'%s' is an error"),
@@ -177,7 +177,7 @@ validation_eval (WorkbookControl *wbc, MStyle const *mstyle,
 					break;
 				}
 			} else
-				res = value_duplicate (val);
+				res = value_dup (val);
 
 			if (v->type == VALIDATION_TYPE_AS_INT &&
 			    res != NULL && res->type == VALUE_FLOAT) {
@@ -242,10 +242,10 @@ validation_eval (WorkbookControl *wbc, MStyle const *mstyle,
 		}
 
 		if (expr != NULL) {
-			ParsePos  pp;
-			EvalPos   ep;
+			GnmParsePos  pp;
+			GnmEvalPos   ep;
 			char	 *expr_str;
-			Value    *val;
+			GnmValue    *val;
 			gboolean  dummy, valid;
 
 			eval_pos_init_cell (&ep, cell);
