@@ -27,18 +27,20 @@
 #include <sheet-view.h>
 #include <selection.h>
 #include <commands.h>
+#include <format.h>
 #include <gnm-marshalers.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkcelleditable.h>
+#include <gtk/gtkimage.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
 
 typedef struct {
 	int text_start;
 	int text_end;
-	RangeRef ref;
+	GnmRangeRef ref;
 	gboolean  is_valid;
 } Rangesel;
 
@@ -106,13 +108,13 @@ static gboolean
 split_char_p (unsigned char const *c)
 {
 	switch (*c) {
-	case ',': case '=':
+	case '=':
 	case '(': case '<': case '>':
 	case '+': case '-': case '*': case '/':
 	case '^': case '&': case '%': case '!':
 		return TRUE;
 	default :
-		return FALSE;
+		return *c == format_get_arg_sep () || *c == format_get_col_sep ();
 	}
 }
 
@@ -123,7 +125,7 @@ gee_rangesel_reset (GnmExprEntry *gee)
 
 	rs->text_start = 0;
 	rs->text_end = 0;
-	memset (&rs->ref, 0, sizeof (Range));
+	memset (&rs->ref, 0, sizeof (GnmRange));
 
 	/* restore the default based on the flags */
 	rs->ref.a.col_relative = rs->ref.b.col_relative = (gee->flags & GNM_EE_ABS_COL) != 0;
@@ -520,7 +522,7 @@ GSF_CLASS_FULL (GnmExprEntry, gnm_expr_entry,
  * Adjust @dst as necessary to conform to @gee's requirements
  **/
 static void
-gee_prepare_range (GnmExprEntry const *gee, RangeRef *dst)
+gee_prepare_range (GnmExprEntry const *gee, GnmRangeRef *dst)
 {
 	Rangesel const *rs = &gee->rangesel;
 
@@ -537,8 +539,8 @@ gee_prepare_range (GnmExprEntry const *gee, RangeRef *dst)
 
 	/* special case a single merge to be only corner */
 	if (!(gee->flags & (GNM_EE_FULL_ROW|GNM_EE_FULL_COL))) {
-		Range const *merge;
-		CellPos  corner;
+		GnmRange const *merge;
+		GnmCellPos  corner;
 
 		corner.col = MIN (dst->a.col, dst->b.col);
 		corner.row = MIN (dst->a.row, dst->b.row);
@@ -546,8 +548,8 @@ gee_prepare_range (GnmExprEntry const *gee, RangeRef *dst)
 		if (merge != NULL &&
 		    merge->end.col == MAX (dst->a.col, dst->b.col) &&
 		    merge->end.row == MAX (dst->a.row, dst->b.row)) {
-			dst->a.col = dst->b.col;
-			dst->a.row = dst->b.row;
+			dst->b.col = dst->a.col;
+			dst->b.row = dst->a.row;
 		}
 	}
 
@@ -558,8 +560,8 @@ gee_prepare_range (GnmExprEntry const *gee, RangeRef *dst)
 static char *
 gee_rangesel_make_text (GnmExprEntry const *gee)
 {
-	RangeRef ref;
-	ParsePos pp;
+	GnmRangeRef ref;
+	GnmParsePos pp;
 	GString *target = g_string_new (NULL);
 
 	gee_prepare_range (gee, &ref);
@@ -619,9 +621,9 @@ gnm_expr_expr_find_range (GnmExprEntry *gee)
 {
 	gboolean  single, formula_only;
 	char const *text, *cursor, *tmp, *ptr;
-	RangeRef  range;
+	GnmRangeRef  range;
 	Rangesel *rs;
-	ParsePos  pp;
+	GnmParsePos  pp;
 	int len;
 
 	g_return_if_fail (gee != NULL);
@@ -907,8 +909,8 @@ gnm_expr_entry_thaw (GnmExprEntry *gee)
  * %GNM_EE_SINGLE_RANGE      Entry will only hold a single range.
  * %GNM_EE_ABS_COL           Column reference must be absolute.
  * %GNM_EE_ABS_ROW           Row reference must be absolute.
- * %GNM_EE_FULL_COL          Range consists of full columns.
- * %GNM_EE_FULL_ROW          Range consists of full rows.
+ * %GNM_EE_FULL_COL          GnmRange consists of full columns.
+ * %GNM_EE_FULL_ROW          GnmRange consists of full rows.
  * %GNM_EE_SHEET_OPTIONAL    Current sheet name not auto-added.
  **/
 void
@@ -985,7 +987,7 @@ gnm_expr_entry_load_from_text (GnmExprEntry *gee, char const *txt)
  * range selections.
  **/
 void
-gnm_expr_entry_load_from_dep (GnmExprEntry *gee, Dependent const *dep)
+gnm_expr_entry_load_from_dep (GnmExprEntry *gee, GnmDependent const *dep)
 {
 	g_return_if_fail (IS_GNM_EXPR_ENTRY (gee));
 	g_return_if_fail (dep != NULL);
@@ -993,7 +995,7 @@ gnm_expr_entry_load_from_dep (GnmExprEntry *gee, Dependent const *dep)
 	g_return_if_fail (gee->freeze_count == 0);
 
 	if (dep->expression != NULL) {
-		ParsePos pp;
+		GnmParsePos pp;
 		char *text = gnm_expr_as_string (dep->expression,
 			parse_pos_init_dep (&pp, dep), gnm_expr_conventions_default);
 
@@ -1016,7 +1018,7 @@ gnm_expr_entry_load_from_dep (GnmExprEntry *gee, Dependent const *dep)
  **/
 void
 gnm_expr_entry_load_from_expr (GnmExprEntry *gee,
-			       GnmExpr const *expr, ParsePos const *pp)
+			       GnmExpr const *expr, GnmParsePos const *pp)
 {
 	g_return_if_fail (IS_GNM_EXPR_ENTRY (gee));
 	/* We have nowhere to store the text while frozen. */
@@ -1036,7 +1038,7 @@ gnm_expr_entry_load_from_expr (GnmExprEntry *gee,
 /**
  * gnm_expr_entry_load_from_range
  * @gee: a #GnmExprEntry
- * @r:          a #Range
+ * @r:          a #GnmRange
  * @sheet:      a #sheet
  * @pos:        position
  *
@@ -1049,7 +1051,7 @@ gnm_expr_entry_load_from_expr (GnmExprEntry *gee,
  **/
 gboolean
 gnm_expr_entry_load_from_range (GnmExprEntry *gee,
-				Sheet *sheet, Range const *r)
+				Sheet *sheet, GnmRange const *r)
 {
 	Rangesel *rs;
 	gboolean needs_change = FALSE;
@@ -1095,19 +1097,19 @@ gnm_expr_entry_load_from_range (GnmExprEntry *gee,
 /**
  * gnm_expr_entry_get_rangesel
  * @gee: a #GnmExprEntry
- * @r:          address to receive #Range
+ * @r:          address to receive #GnmRange
  * @sheet:      address to receive #sheet
  *
- * Get the range selection. Range is copied, Sheet is not. If sheet
+ * Get the range selection. GnmRange is copied, Sheet is not. If sheet
  * argument is NULL, the corresponding value is not returned.
  * Returns TRUE if the returned range is indeed valid.
  * The resulting range is normalized.
  **/
 gboolean
 gnm_expr_entry_get_rangesel (GnmExprEntry *gee,
-			     Range *r, Sheet **sheet)
+			     GnmRange *r, Sheet **sheet)
 {
-	RangeRef ref;
+	GnmRangeRef ref;
 	Rangesel const *rs = &gee->rangesel;
 
 	g_return_val_if_fail (IS_GNM_EXPR_ENTRY (gee), FALSE);
@@ -1220,8 +1222,8 @@ gnm_expr_entry_can_rangesel (GnmExprEntry *gee)
  * the flags.
  */
 GnmExpr const *
-gnm_expr_entry_parse (GnmExprEntry *gee, ParsePos const *pp,
-		      ParseError *perr, gboolean start_sel,
+gnm_expr_entry_parse (GnmExprEntry *gee, GnmParsePos const *pp,
+		      GnmParseError *perr, gboolean start_sel,
 		      GnmExprParseFlags flags)
 {
 	char const *text;
@@ -1247,7 +1249,7 @@ gnm_expr_entry_parse (GnmExprEntry *gee, ParsePos const *pp,
 		return NULL;
 
 	if (gee->flags & GNM_EE_SINGLE_RANGE) {
-		Value *range = gnm_expr_get_range (expr) ;
+		GnmValue *range = gnm_expr_get_range (expr) ;
 		if (range == NULL) {
 			if (perr != NULL) {
 				perr->err = g_error_new (1, PERR_SINGLE_RANGE,
@@ -1298,10 +1300,10 @@ gnm_expr_entry_get_text	(GnmExprEntry const *gee)
  * @sheet: the sheet where the cell range is evaluated. This really only needed if
  *         the range given does not include a sheet specification.
  *
- * Returns a (Value *) of type VALUE_CELLRANGE if the @range was
+ * Returns a (GnmValue *) of type VALUE_CELLRANGE if the @range was
  *	succesfully parsed or NULL on failure.
  */
-Value *
+GnmValue *
 gnm_expr_entry_parse_as_value (GnmExprEntry *gee, Sheet *sheet)
 {
 	g_return_val_if_fail (IS_GNM_EXPR_ENTRY (gee), NULL);
@@ -1341,7 +1343,7 @@ gboolean
 gnm_expr_entry_is_cell_ref (GnmExprEntry *gee, Sheet *sheet,
 			    gboolean allow_multiple_cell)
 {
-        Value *val;
+        GnmValue *val;
 	gboolean res;
 
 	g_return_val_if_fail (IS_GNM_EXPR_ENTRY (gee), FALSE);
@@ -1382,7 +1384,7 @@ gnm_expr_entry_is_blank	(GnmExprEntry *gee)
 char *
 gnm_expr_entry_global_range_name (GnmExprEntry *gee, Sheet *sheet)
 {
-	Value *val;
+	GnmValue *val;
 	char *text = NULL;
 
 	g_return_val_if_fail (IS_GNM_EXPR_ENTRY (gee), NULL);
